@@ -343,11 +343,10 @@ class BaseBot:
                                              channel=msg.channel_name)
                 event_coro = trigger_event(Event.on_channel_points_redemption, msg, msg.reward)
 
-            if msg.is_privmsg and msg.tags and msg.tags.bits:
-                get_event_loop().create_task(self.on_bits_donated(msg, msg.tags.bits))
-                get_event_loop().create_task(
-                    trigger_mod_event(Event.on_bits_donated, msg, msg.tags.bits, channel=msg.channel_name))
-                get_event_loop().create_task(trigger_event(Event.on_bits_donated, msg.channel, msg))
+            elif msg.type is MessageType.BITS:
+                coro = self.on_bits_donated(msg, msg.tags.bits)
+                mod_coro = trigger_mod_event(Event.on_bits_donated, msg, msg.tags.bits, channel=msg.channel_name)
+                event_coro = trigger_event(Event.on_bits_donated, msg.channel, msg)
 
             if coro is not None:
                 get_event_loop().create_task(coro)
